@@ -7,7 +7,7 @@
  Authors:      see AUTHORS
  Copyright:    see AUTHORS
  License:      see LICENSE
- Last Updated: 11/15/2019
+ Last Updated: 02/03/2020
  ******************************************************************************
 */
 
@@ -253,6 +253,8 @@ void initpointers(Project *pr)
     pr->hydraul.P = NULL;
     pr->hydraul.Y = NULL;
     pr->hydraul.Xflow = NULL;
+    pr->hydraul.DemandFlow = NULL;
+    pr->hydraul.EmitterFlow = NULL;
 
     pr->quality.NodeQual = NULL;
     pr->quality.PipeRateCoeff = NULL;
@@ -313,10 +315,14 @@ int allocdata(Project *pr)
         pr->hydraul.NodeDemand = (double *)calloc(n, sizeof(double));
         pr->hydraul.NodeHead   = (double *)calloc(n, sizeof(double));
         pr->quality.NodeQual   = (double *)calloc(n, sizeof(double));
+        pr->hydraul.DemandFlow  = (double *)calloc(n, sizeof(double));
+        pr->hydraul.EmitterFlow = (double *)calloc(n, sizeof(double));
         ERRCODE(MEMCHECK(pr->network.Node));
         ERRCODE(MEMCHECK(pr->hydraul.NodeDemand));
         ERRCODE(MEMCHECK(pr->hydraul.NodeHead));
         ERRCODE(MEMCHECK(pr->quality.NodeQual));
+        ERRCODE(MEMCHECK(pr->hydraul.DemandFlow));
+        ERRCODE(MEMCHECK(pr->hydraul.EmitterFlow));
     }
 
     // Allocate memory for network links
@@ -388,6 +394,8 @@ void freedata(Project *pr)
     free(pr->hydraul.LinkFlow);
     free(pr->hydraul.LinkSetting);
     free(pr->hydraul.LinkStatus);
+    free(pr->hydraul.DemandFlow);
+    free(pr->hydraul.EmitterFlow);
     free(pr->quality.NodeQual);
 
     // Free memory used for nodal adjacency lists
@@ -795,6 +803,35 @@ int valvecheck(Project *pr, int index, int type, int j1, int j2)
     return 0;
 }
 
+int unlinked(Project *pr)
+/*
+**--------------------------------------------------------------
+** Input:   none
+** Output:  returns error code if any unlinked junctions found
+** Purpose: checks for unlinked junctions in network
+**
+** NOTE: unlinked tanks have no effect on computations.
+**--------------------------------------------------------------
+*/
+{
+    Network *net = &pr->network;
+    int i, count = 0;
+	char errmsg[MAXMSG + 1] = "";
+    
+    for (i = 1; i <= net->Njuncs; i++)
+    {
+        if (pr->network.Adjlist[i] == NULL)
+        {
+            count++;
+            sprintf(pr->Msg, "Error 234: %s %s", geterrmsg(234, errmsg), net->Node[i].ID);
+            writeline(pr, pr->Msg);
+        }
+        if (count >= 10) break;
+    }
+    if (count > 0) return 233;
+    return 0;
+}    
+
 int findnode(Network *network, char *id)
 /*----------------------------------------------------------------
 **  Input:   id = node ID
@@ -912,8 +949,8 @@ void adjustpattern(int *pat, int index)
 **----------------------------------------------------------------
 */
 {
-	if (*pat == index) *pat = 0;
-	else if (*pat > index) (*pat)--;
+    if (*pat == index) *pat = 0;
+    else if (*pat > index) (*pat)--;
 }
 
 void adjustpatterns(Network *network, int index)
